@@ -28,9 +28,9 @@
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-help.h>
 #include <profiles/gnome-media-profiles.h>
+#include <nautilus-burn-drive.h>
+#include <nautilus-burn-drive-selection.h>
 #include "sj-extracting.h"
-#include "cd-drive.h"
-#include "bacon-cd-selection.h"
 
 extern GladeXML *glade;
 extern GtkWidget *main_window;
@@ -71,8 +71,8 @@ const char* prefs_get_default_device ()
 {
   static const char* default_device = NULL;
   if (default_device == NULL) {
-    CDDrive *cd;
-    cdroms = scan_for_cdroms (FALSE, FALSE);
+    NautilusBurnDrive *cd;
+    cdroms = nautilus_burn_drive_get_list (FALSE, FALSE);
     if (cdroms == NULL) return NULL;
     cd = cdroms->data;
     default_device = cd->device;
@@ -85,10 +85,10 @@ gboolean cd_drive_exists (const char *device)
   GList *l;
   if (device == NULL) return FALSE;
   if (cdroms == NULL) {
-    cdroms = scan_for_cdroms (FALSE, FALSE);
+    cdroms = nautilus_burn_drive_get_list (FALSE, FALSE);
   }
   for (l = cdroms; l != NULL; l = l->next) {
-    if (strcmp (((CDDrive *) (l->data))->device, device) == 0)
+    if (strcmp (((NautilusBurnDrive *) (l->data))->device, device) == 0)
       return TRUE;
   }
   return FALSE;
@@ -115,12 +115,9 @@ void prefs_eject_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 void prefs_profile_changed (GtkWidget *widget, gpointer user_data)
 {
   GMAudioProfile *profile;
-  /* Handle the change being to unselect a profile */
-  if (gtk_combo_box_get_active (GTK_COMBO_BOX (widget)) != -1) {
-    profile = gm_audio_profile_choose_get_active (widget);
-    gconf_client_set_string (gconf_client, GCONF_AUDIO_PROFILE,  
-                             gm_audio_profile_get_id (profile), NULL);
-  }
+  profile = gm_audio_profile_choose_get_active (widget);
+  gconf_client_set_string (gconf_client, GCONF_AUDIO_PROFILE,  
+			   gm_audio_profile_get_id (profile), NULL);
 }
 
 /**
@@ -199,11 +196,11 @@ static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
   g_return_if_fail (strcmp (entry->key, GCONF_DEVICE) == 0);
 
   if (entry->value == NULL) {
-    bacon_cd_selection_set_device (BACON_CD_SELECTION (cd_option),
-                                   bacon_cd_selection_get_default_device (BACON_CD_SELECTION (cd_option)));
+    nautilus_burn_drive_selection_set_device (NAUTILUS_BURN_DRIVE_SELECTION (cd_option),
+                                   nautilus_burn_drive_selection_get_default_device (NAUTILUS_BURN_DRIVE_SELECTION (cd_option)));
   } else {
     g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
-    bacon_cd_selection_set_device (BACON_CD_SELECTION (cd_option),
+    nautilus_burn_drive_selection_set_device (NAUTILUS_BURN_DRIVE_SELECTION (cd_option),
                                    gconf_value_get_string (entry->value));
   }
 }
@@ -211,13 +208,17 @@ static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
 static void audio_profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   const char *value;
+  GMAudioProfile *profile;
   g_return_if_fail (strcmp (entry->key, GCONF_AUDIO_PROFILE) == 0);
   if (!entry->value) return;
   value = gconf_value_get_string (entry->value);
   
-  /* If the value is empty, unset the combo. Otherwise try and set it. */
   if (strcmp (value, "") == 0) {
-    gtk_combo_box_set_active (GTK_COMBO_BOX (audio_profile), -1);
+    /* If there is a current profile use it otherwise use the default */
+    profile = gm_audio_profile_choose_get_active (audio_profile);
+    if (profile == NULL) {
+      gm_audio_profile_choose_set_active (audio_profile, DEFAULT_AUDIO_PROFILE_NAME);
+    }
   } else {
     gm_audio_profile_choose_set_active (audio_profile, value);
   }
@@ -330,6 +331,7 @@ static void path_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
   char *value;
   int i = 0;
   g_return_if_fail (strcmp (entry->key, GCONF_PATH_PATTERN) == 0);
+  g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
 
   if (entry->value == NULL) {
     value = g_strdup (path_patterns[0].pattern);
@@ -351,6 +353,7 @@ static void file_pattern_changed_cb (GConfClient *client, guint cnxn_id, GConfEn
   int i = 0;
   
   g_return_if_fail (strcmp (entry->key, GCONF_FILE_PATTERN) == 0);
+  g_return_if_fail (entry->value->type == GCONF_VALUE_STRING);
   
   if (entry->value == NULL) {
     value = g_strdup (file_patterns[0].pattern);
@@ -440,8 +443,3 @@ void on_edit_preferences_cb (GtkMenuItem *item, gpointer user_data)
       
   gtk_widget_hide (prefs_dialog);
 }
-
-GtkWidget* create_file_chooser_button(void)
-{
-  return gtk_file_chooser_button_new (_("Select Folder"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
-}
